@@ -4,7 +4,7 @@
 # Ben Bass 2012-2014 @codedstructure
 
 
-__version__ = '0.3'
+__version__ = '0.3.2'
 
 import os
 import sys
@@ -22,6 +22,17 @@ except ImportError:
     from ConfigParser import RawConfigParser
 
 
+USAGE_FORMAT_STR = """
+{} v{} - should be used via named symlinks
+  config file: {}
+"""
+
+# Avoid using __file__ due to packaging concerns.
+URLSEARCH_SCRIPT = "urlsearch"
+NORMAL_CONFIG_PATH = os.path.expanduser('~/.urlsearchrc')
+DEFAULT_CONFIG_PATH = os.path.expanduser('~/.urlsearchrc.default')
+
+
 class UrlSearcher(object):
     def __init__(self, site, search, configfile=None):
         self.site = site
@@ -33,12 +44,23 @@ class UrlSearcher(object):
         self.hash_num = False
 
         if configfile is None:
-            configfile = self.get_config_file()
+            configfile = UrlSearcher.get_config_file()
 
         self.read_config(configfile)
 
-    def get_config_file(self):
-        return ['.urlsearchrc', os.path.expanduser('~/.urlsearchrc')]
+    @staticmethod
+    def get_config_file():
+        for fn in (NORMAL_CONFIG_PATH, DEFAULT_CONFIG_PATH):
+            if os.path.exists(fn):
+                return fn
+        else:
+            from .default_config import URLSEARCHRC_CONFIG
+            with open(DEFAULT_CONFIG_PATH, 'w') as f:
+                f.write(URLSEARCHRC_CONFIG)
+            print("Written default urlsearch config file to {}".format(
+                DEFAULT_CONFIG_PATH))
+
+            return DEFAULT_CONFIG_PATH
 
     def read_config(self, configpath):
         parser = RawConfigParser({
@@ -112,9 +134,9 @@ def main():
     search = ' '.join(sys.argv[1:])
 
     # blacklist 'urlsearch'
-    if (os.path.basename(sys.argv[0]) ==
-            os.path.splitext(os.path.basename(__file__))[0]):
-        raise SystemExit("Should be used via named symlinks")
+    if site == URLSEARCH_SCRIPT:
+        raise SystemExit(USAGE_FORMAT_STR.format(
+            site, __version__, UrlSearcher.get_config_file()))
 
     urlsearch = UrlSearcher(site, search)
     urlsearch.open()
